summaryrefslogtreecommitdiff
path: root/sw/inc/ndnotxt.hxx
diff options
context:
space:
mode:
authorMathias Bauer <mba@openoffice.org>2011-02-09 09:49:44 +0100
committerMathias Bauer <mba@openoffice.org>2011-02-09 09:49:44 +0100
commit53b8f0865ff2e59cb71eaf4c1bdbc829238fde6f (patch)
tree31528d76013d09428fad98a3dbc6265345dbbeb9 /sw/inc/ndnotxt.hxx
parente22a1e2f5c5ed74c22849c9b5bb59dd8f47bffbc (diff)
parent9730661364792059168a06bfbaacf47fc8daf53c (diff)
CWS swlayoutrefactoring: resync to m100
Diffstat (limited to 'sw/inc/ndnotxt.hxx')
-rw-r--r--sw/inc/ndnotxt.hxx30
1 files changed, 15 insertions, 15 deletions
diff --git a/sw/inc/ndnotxt.hxx b/sw/inc/ndnotxt.hxx
index cf0b60724e0c..5aab4f9a5708 100644
--- a/sw/inc/ndnotxt.hxx
+++ b/sw/inc/ndnotxt.hxx
@@ -43,11 +43,11 @@ class SW_DLLPUBLIC SwNoTxtNode : public SwCntntNode
// String aAlternateText; // alternativer Text (HTML)
PolyPolygon *pContour; // Polygon fuer Konturumlauf
- BOOL bAutomaticContour : 1; // automatic contour polygon, not manipulated
- BOOL bContourMapModeValid : 1; // contour map mode is not the graphics's
+ sal_Bool bAutomaticContour : 1; // automatic contour polygon, not manipulated
+ sal_Bool bContourMapModeValid : 1; // contour map mode is not the graphics's
// prefered map mode, but either
// MM100 or or pixel
- BOOL bPixelContour : 1; // contour map mode is invalid and pixel.
+ sal_Bool bPixelContour : 1; // contour map mode is invalid and pixel.
// erzeugt fuer alle Ableitungen einen AttrSet mit Bereichen
// fuer Frame- und Grafik-Attributen (wird nur vom SwCntntNode gerufen)
@@ -57,7 +57,7 @@ class SW_DLLPUBLIC SwNoTxtNode : public SwCntntNode
SwNoTxtNode &operator=( const SwNoTxtNode& ); //nicht erlaubt
protected:
- SwNoTxtNode( const SwNodeIndex &rWhere, const BYTE nNdType,
+ SwNoTxtNode( const SwNodeIndex &rWhere, const sal_uInt8 nNdType,
SwGrfFmtColl *pGrColl, SwAttrSet* pAutoAttr = 0 );
public:
@@ -69,8 +69,8 @@ public:
virtual Size GetTwipSize() const = 0;
- virtual BOOL SavePersistentData();
- virtual BOOL RestorePersistentData();
+ virtual sal_Bool SavePersistentData();
+ virtual sal_Bool RestorePersistentData();
const String GetTitle() const;
void SetTitle( const String& rTitle,
@@ -84,25 +84,25 @@ public:
// sal_Bool bBroadcast=sal_False );
void SetContour( const PolyPolygon *pPoly,
- BOOL bAutomatic = FALSE );
+ sal_Bool bAutomatic = sal_False );
const PolyPolygon *HasContour() const;
- BOOL _HasContour() const { return pContour!=0; };
+ sal_Bool _HasContour() const { return pContour!=0; };
void GetContour( PolyPolygon &rPoly ) const;
void CreateContour();
- void SetAutomaticContour( BOOL bSet ) { bAutomaticContour = bSet; }
- BOOL HasAutomaticContour() const { return bAutomaticContour; }
+ void SetAutomaticContour( sal_Bool bSet ) { bAutomaticContour = bSet; }
+ sal_Bool HasAutomaticContour() const { return bAutomaticContour; }
// set either a MM100 or pixel contour
void SetContourAPI( const PolyPolygon *pPoly );
- // get either a MM100 or pixel contour, return FALSE if no contour is set.
- BOOL GetContourAPI( PolyPolygon &rPoly ) const;
+ // get either a MM100 or pixel contour, return sal_False if no contour is set.
+ sal_Bool GetContourAPI( PolyPolygon &rPoly ) const;
- void SetPixelContour( BOOL bSet ) { bPixelContour = bSet; }
- BOOL IsPixelContour() const;
+ void SetPixelContour( sal_Bool bSet ) { bPixelContour = bSet; }
+ sal_Bool IsPixelContour() const;
- BOOL IsContourMapModeValid() const { return bContourMapModeValid; }
+ sal_Bool IsContourMapModeValid() const { return bContourMapModeValid; }
//Besorgt die Graphic, mit SwapIn fuer GrfNode, per GetData fuer OLE.
Graphic GetGraphic() const;